@@ -1,7 +1,7 @@
-#' @include get_RLum.R set_RLum.R names_RLum.R length_RLum.R bin_RLum.Data.R
+#' @include get_RLum.R set_RLum.R names_RLum.R length_RLum.R bin_RLum.Data.R smooth_RLum.R
 NULL
 
-#' Class \code{"RLum.Data.Curve"}
+#' Class `"RLum.Data.Curve"`
 #'
 #' Class for representing luminescence curve data.
 #'
@@ -9,33 +9,42 @@ NULL
 #'
 #' @docType class
 #'
-#' @slot recordType Object of class "character" containing the type of the curve (e.g. "TL" or "OSL")
+#' @slot recordType
+#' Object of class "character" containing the type of the curve (e.g. "TL" or "OSL")
 #'
-#' @slot curveType Object of class "character" containing curve type, allowed values are measured or predefined
+#' @slot curveType
+#' Object of class "character" containing curve type, allowed values are measured or predefined
 #'
-#' @slot data Object of class \code{\link{matrix}} containing curve x and y data.
-#' 'data' can also be of type \code{RLum.Data.Curve} to change object values without deconstructing the object.
-#' For example: \code{set_RLum(class = 'RLum.Data.Curve',
-#' data = Your.RLum.Data.Curve, recordType = 'never seen before')}
-#' would just change the recordType. Missing arguements  the value is taken from the input object
-#' in 'data' (which is already an RLum.Data.Curve object in this example)
+#' @slot data
+#' Object of class [matrix] containing curve x and y data.
+#' 'data' can also be of type `RLum.Data.Curve` to change object values without
+#' deconstructing the object. For example:
+#' ```
+#' set_RLum(class = 'RLum.Data.Curve',
+#'          data = Your.RLum.Data.Curve,
+#'          recordType = 'never seen before')
+#' ```
+#' would just change the recordType. Missing arguements  the value is taken
+#' from the input object in 'data' (which is already an RLum.Data.Curve object
+#' in this example)
 #'
 #'
-#' @note The class should only contain data for a single curve. For additional
-#' elements the slot \code{info} can be used (e.g. providing additional heating
-#' ramp curve). Objects from the class \code{RLum.Data.Curve} are produced by other
-#' functions (partyl within \code{\linkS4class{RLum.Analysis}} objects),
-#' namely: \code{\link{Risoe.BINfileData2RLum.Analysis}}, \code{\link{read_XSYG2R}}
+#' @note
+#' The class should only contain data for a single curve. For additional
+#' elements the slot `info` can be used (e.g. providing additional heating
+#' ramp curve). Objects from the class `RLum.Data.Curve` are produced by other
+#' functions (partyl within [RLum.Analysis-class] objects),
+#' namely: [Risoe.BINfileData2RLum.Analysis], [read_XSYG2R]
 #'
-#' @section Create objects from this Class: Objects can be created by calls of the form
-#' \code{set_RLum(class = "RLum.Data.Curve", ...)}.
+#' @section Create objects from this Class:
+#' Objects can be created by calls of the form
+#' `set_RLum(class = "RLum.Data.Curve", ...)`.
 #'
-#' @section Class version: 0.4.1
+#' @section Class version: 0.5.0
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
 #'
-#' @seealso \code{\linkS4class{RLum}}, \code{\linkS4class{RLum.Data}},
-#' \code{\link{plot_RLum}}, \code{\link{merge_RLum}}
+#' @seealso [RLum-class], [RLum.Data-class], [plot_RLum], [merge_RLum]
 #'
 #' @keywords classes
 #'
@@ -46,6 +55,7 @@ NULL
 #' ##set empty curve object
 #' set_RLum(class = "RLum.Data.Curve")
 #'
+#' @md
 #' @export
 setClass("RLum.Data.Curve",
          slots = list(
@@ -66,32 +76,34 @@ setClass("RLum.Data.Curve",
 ####################################################################################################
 ##LIST
 ##COERCE RLum.Data.Curve >> list AND list >> RLum.Data.Curve
+
 #' as() - RLum-object coercion
 #'
-#' for \code{[RLum.Data.Curve]}
+#' for `[RLum.Data.Curve-class]`
 #'
-#' \bold{[RLum.Data.Curve]}\cr
+#' **[RLum.Data.Curve-class]**
 #'
 #' \tabular{ll}{
-#'  \bold{from} \tab \bold{to}\cr
-#'   \code{list} \tab \code{list} \cr
-#'   \code{data.frame} \tab \code{data.frame}\cr
-#'   \code{matrix} \tab \code{matrix}
-#'
+#'  **from** \tab **to**\cr
+#'   `list` \tab `list` \cr
+#'   `data.frame` \tab `data.frame`\cr
+#'   `matrix` \tab `matrix`
 #' }
 #'
-#' @param from \code{\linkS4class{RLum}} or \code{\link{list}}, \code{\link{data.frame}}, \code{\link{matrix}}
-#' (\bold{required}): object to be coerced from
+#' @param from [RLum-class], [list], [data.frame], [matrix] (**required**):
+#'  object to be coerced from
 #'
-#' @param to \code{\link{character}} (\bold{required}): class name to be coerced to
+#' @param to [character] (**required**):
+#' class name to be coerced to
 #'
-#' @seealso \code{\link[methods]{as}}
+#' @seealso [methods::as]
 #'
-#' @note Due to the complex structure of the \code{RLum} objects itself a coercing to standard
+#' @note
+#' Due to the complex structure of the `RLum` objects itself a coercing to standard
 #' R data structures will be always loosely!
 #'
+#' @md
 #' @name as
-#'
 setAs("list", "RLum.Data.Curve",
       function(from,to){
 
@@ -156,7 +168,11 @@ setAs("RLum.Data.Curve", "matrix",
 ###show()
 ####################################################################################################
 #' @describeIn RLum.Data.Curve
-#' Show structure of \code{RLum.Data.Curve} object
+#' Show structure of `RLum.Data.Curve` object
+#'
+#' @keywords internal
+#'
+#' @md
 #' @export
 setMethod("show",
           signature(object = "RLum.Data.Curve"),
@@ -164,13 +180,16 @@ setMethod("show",
 
 
             ##print information
-
-            cat("\n [RLum.Data.Curve]")
+            cat("\n [RLum.Data.Curve-class]")
             cat("\n\t recordType:", object@recordType)
             cat("\n\t curveType:",  object@curveType)
             cat("\n\t measured values:", length(object@data[,1]))
             cat("\n\t .. range of x-values:", suppressWarnings(range(object@data[,1])))
-            cat("\n\t .. range of y-values:",  suppressWarnings(range(object@data[,2])))
+            cat("\n\t .. range of y-values:",
+                suppressWarnings(min(object@data[,2], na.rm = TRUE)),
+                suppressWarnings(max(object@data[,2], na.rm = TRUE)),
+                if(anyNA(object@data[,2])){"(contains NA values)"}else{""}
+               )
             cat("\n\t additional info elements:", length(object@info))
             #cat("\n\t\t >> names:", names(object@info))
           }
@@ -186,26 +205,39 @@ setMethod("show",
 #' Construction method for RLum.Data.Curve object. The slot info is optional
 #' and predefined as empty list by default.
 #'
-#' @param class [\code{set_RLum}] \code{\link{character}} (\bold{required}): name of the \code{RLum} class to create
-#' @param originator [\code{set_RLum}] \code{\link{character}} (automatic): contains the name of the calling function
-#' (the function that produces this object); can be set manually.
-#' @param .uid [\code{set_RLum}] \code{\link{character}} (automatic): sets an unique ID for this object
-#' using the internal C++ function \code{.create_UID}.
-#' @param .pid [\code{set_RLum}] \code{\link{character}} (with default): option to provide a parent id for nesting
-#' at will.
-#' @param recordType [\code{set_RLum}] \code{\link{character}} (optional): record type (e.g., "OSL")
-#' @param curveType [\code{set_RLum}] \code{\link{character}} (optional): curve type (e.g., "predefined" or "measured")
-#' @param data [\code{set_RLum}] \code{\link{matrix}} (\bold{required}): raw curve data.
-#' If \code{data} itself is a \code{RLum.Data.Curve}-object this can be used to re-construct the object
-#' (s. Details)
-#' @param info [\code{set_RLum}] \code{\link{list}} (optional): info elements
+#' @param class [`set_RLum`]; [character] (**required**):
+#' name of the `RLum` class to create
+#'
+#' @param originator [`set_RLum`]; [character] (*automatic*):
+#' contains the name of the calling function (the function that produces this object);
+#' can be set manually.
+#'
+#' @param .uid [`set_RLum`]; [character] (*automatic*):
+#' sets an unique ID for this object using the internal C++ function `create_UID`.
+#'
+#' @param .pid [`set_RLum`]; [character] (*with default*):
+#' option to provide a parent id for nesting at will.
+#'
+#' @param recordType [`set_RLum`]; [character] (*optional*):
+#' record type (e.g., "OSL")
+#'
+#' @param curveType [`set_RLum`]; [character] (*optional*):
+#' curve type (e.g., "predefined" or "measured")
+#'
+#' @param data [`set_RLum`]; [matrix] (**required**):
+#' raw curve data. If `data` itself is a `RLum.Data.Curve`-object this can be
+#' used to re-construct the object (s. Details)
+#'
+#' @param info [`set_RLum`]; [list] (*optional*):
+#' info elements
 #'
 #' @return
 #'
-#' \bold{\code{set_RLum}}\cr
+#' **`set_RLum`**
 #'
-#' Returns an \code{\linkS4class{RLum.Data.Curve}} object.
+#' Returns an [RLum.Data.Curve-class] object.
 #'
+#' @md
 #' @export
 setMethod(
   "set_RLum",
@@ -246,42 +278,49 @@ setMethod(
 
       ##check for missing .uid
       if(missing(.uid)){
-        info <- data@.uid
+        .uid <- data@.uid
 
       }
 
       ##check for missing .pid
       if(missing(.pid)){
-        info <- data@.pid
+        .pid <- data@.pid
 
       }
 
-      ##set empty clas form object
+      ##check for missing originator
+      if(missing(originator)){
+        originator <- data@originator
+
+      }
+
+      ##set empty class from object
       newRLumDataCurve <- new("RLum.Data.Curve")
 
       ##fill - this is the faster way, filling in new() costs ...
-      newRLumDataCurve@recordType = recordType
-      newRLumDataCurve@curveType = curveType
-      newRLumDataCurve@data = data@data
-      newRLumDataCurve@info = info
-      newRLumDataCurve@.uid = data@.uid
-      newRLumDataCurve@.pid = data@.pid
+      newRLumDataCurve@recordType <- recordType
+      newRLumDataCurve@curveType <- curveType
+      newRLumDataCurve@data <- data@data
+      newRLumDataCurve@info <- info
+      newRLumDataCurve@originator <- originator
+      newRLumDataCurve@.uid <- .uid
+      newRLumDataCurve@.pid <- .pid
 
       return(newRLumDataCurve)
 
     }else{
 
-      ##set empty clas form object
+      ##set empty class form object
       newRLumDataCurve <- new("RLum.Data.Curve")
 
       ##fill - this is the faster way, filling in new() costs ...
-      newRLumDataCurve@originator = originator
-      newRLumDataCurve@recordType = recordType
-      newRLumDataCurve@curveType = curveType
-      newRLumDataCurve@data = data
-      newRLumDataCurve@info = info
-      newRLumDataCurve@.uid = .uid
-      newRLumDataCurve@.pid = .pid
+      newRLumDataCurve@originator <- originator
+      newRLumDataCurve@recordType <- recordType
+      newRLumDataCurve@curveType <- curveType
+      newRLumDataCurve@data <- data
+      newRLumDataCurve@info <- info
+      newRLumDataCurve@.uid <- .uid
+      newRLumDataCurve@.pid <- .pid
 
       return(newRLumDataCurve)
 
@@ -298,63 +337,55 @@ setMethod(
 #' optional to directly access the info elements. If no info element name is
 #' provided, the raw curve data (matrix) will be returned.
 #'
-#' @param object [\code{show_RLum}][\code{get_RLum}][\code{length_RLum}][\code{names_RLum}] an object of
-#' class \code{\linkS4class{RLum.Data.Curve}} (\bold{required})
-#' @param info.object [\code{get_RLum}] \code{\link{character}} (optional): name of the wanted info
-#' element
+#' @param object [`get_RLum`], [`length_RLum`], [`names_RLum`] (**required**):
+#' an object of class [RLum.Data.Curve-class]
+#'
+#' @param info.object [`get_RLum`] [character] (*optional*):
+#' name of the wanted info element
 #'
 #' @return
 #'
-#' \bold{\code{get_RLum}}\cr
+#' **`get_RLum`**
 #'
-#' (1) A \code{\link{matrix}} with the curve values or \cr
-#' (2) only the info object if \code{info.object} was set.\cr
+#' 1. A [matrix] with the curve values or
+#' 2. only the info object if `info.object` was set.
 #'
+#' @md
 #' @export
 setMethod("get_RLum",
           signature("RLum.Data.Curve"),
           definition = function(object, info.object = NULL) {
 
            ##Check if function is of type RLum.Data.Curve
-           if(is(object, "RLum.Data.Curve") == FALSE){
-
-              stop("[get_RLum] Function valid for 'RLum.Data.Curve' objects only!")
-
-           }
+           if(class(object) != "RLum.Data.Curve")
+             stop("[get_RLum()] Function valid for 'RLum.Data.Curve' objects only!", call. = FALSE)
 
            ##if info.object == NULL just show the curve values
-          if(!is.null(info.object)) {
-
+           if(!is.null(info.object)) {
               if(info.object %in% names(object@info)){
-
                 unlist(object@info[info.object])
 
               }else{
-
                 ##check for entries
                 if(length(object@info) == 0){
-
-                  warning("[get_RLum] This RLum.Data.Curve object has no info objects! NULL returned!)")
+                  warning("[get_RLum()] This RLum.Data.Curve object has no info objects! NULL returned!)")
                   return(NULL)
 
                 }else{
-
                   ##grep names
                   temp.element.names <- paste(names(object@info), collapse = ", ")
 
-                  warning.text <- paste("[get_RLum] Invalid info.object name. Valid names are:", temp.element.names)
+                  warning.text <- paste("[get_RLum()] Invalid info.object name. Valid names are:", temp.element.names)
 
-                  warning(warning.text, call. = FALSE)
+                   warning(warning.text, call. = FALSE)
                   return(NULL)
 
                 }
 
               }
 
-
              }else{
-
-                    object@data
+                object@data
 
              }
           })
@@ -367,10 +398,12 @@ setMethod("get_RLum",
 #' value time/temperature of the curve (corresponding to the stimulation length)
 #'
 #' @return
-#' \bold{\code{length_RLum}}\cr
+#'
+#' **`length_RLum`**
 #'
 #' Number of channels in the curve (row number of the matrix)
 #'
+#' @md
 #' @export
 setMethod("length_RLum",
           "RLum.Data.Curve",
@@ -387,9 +420,9 @@ setMethod("length_RLum",
 #'
 #' @return
 #'
-#' \bold{\code{names_RLum}}\cr
+#' **`names_RLum`**
 #'
-#' Names of the info elements (slot \code{info})
+#' Names of the info elements (slot `info`)
 #'
 #' @export
 setMethod("names_RLum",
@@ -405,15 +438,17 @@ setMethod("names_RLum",
 #' @describeIn RLum.Data.Curve
 #' Allows binning of specific objects
 #'
-#' @param bin_size [\code{bin_RLum}] \code{\link{integer}} (with default): set number of channels
-#' used for each bin, e.g. \code{bin_size = 2} means that two channels are binned.
+#' @param bin_size [integer] (*with default*):
+#' set number of channels used for each bin, e.g. `bin_size = 2` means that
+#' two channels are binned.
 #'
 #' @return
 #'
-#' \bold{\code{bin_RLum.Data}}\cr
+#' **`bin_RLum.Data`**
 #'
 #' Same object as input, after applying the binning.
 #'
+#' @md
 #' @export
 setMethod(f = "bin_RLum.Data",
           signature = "RLum.Data.Curve",
@@ -449,10 +484,60 @@ setMethod(f = "bin_RLum.Data",
             } else{
               warning("Argument 'bin_size' invald, nothing was done!")
 
-              ##set matrix
-              return(set_RLum(class = "RLum.Data.Curve",
-                              data = object))
+              ##just return the object
+              return(object)
 
             }
 
           })
+
+####################################################################################################
+###smooth_RLum()
+####################################################################################################
+#' @describeIn RLum.Data.Curve
+#' Smoothing of RLum.Data.Curve objects using the function [zoo::rollmean] or [zoo::rollmedian][zoo::rollmean].
+#' In particular the internal function `.smoothing` is used.
+#'
+#' @param k [`smooth_RLum`]; [integer] (*with default*):
+#' window for the rolling mean; must be odd for rollmedian.
+#' If nothing is set k is set automatically
+#'
+#' @param fill [`smooth_RLum`]; [numeric] (*with default*):
+#' a vector defining the left and the right hand data
+#'
+#' @param align [`smooth_RLum`]; [character] (*with default*):
+#' specifying whether the index of the result should be left- or right-aligned
+#' or centered (default) compared to the rolling window of observations, allowed
+#' `"right"`, `"center"` and `"left"`
+#'
+#' @param method [`smooth_RLum`]; [character] (*with default*):
+#' defines which method should be applied for the smoothing: `"mean"` or `"median"`
+#'
+#' @return
+#'
+#' **`smooth_RLum`**
+#'
+#' Same object as input, after smoothing
+#'
+#' @md
+#' @export
+setMethod(
+  f = "smooth_RLum",
+  signature = "RLum.Data.Curve",
+    function(object, k = NULL, fill = NA, align = "right", method = "mean") {
+
+        object@data[,2] <- .smoothing(
+          x = object@data[,2],
+          k = k,
+          fill = fill,
+          align = align,
+          method = method)
+
+        ##return via set function to get a new id
+        set_RLum(class = "RLum.Data.Curve",
+                 originator = "smooth_RLum",
+                 data = object)
+
+    }
+ )
+
